#
# spec file for package libqxmpp
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover 3
Name:           libqxmpp
Version:        1.4.0
Release:        bp154.1.82
Summary:        Qt XMPP Library
License:        LGPL-2.1-or-later
Group:          Development/Libraries/C and C++
URL:            https://github.com/qxmpp-project/qxmpp/
Source0:        https://github.com/qxmpp-project/qxmpp/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        baselibs.conf
BuildRequires:  cmake >= 3.3
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  pkgconfig
BuildRequires:  cmake(Qt5Core) >= 5.7.0
BuildRequires:  cmake(Qt5Gui)
BuildRequires:  cmake(Qt5Network)
BuildRequires:  cmake(Qt5Test)
BuildRequires:  cmake(Qt5Xml)
BuildRequires:  pkgconfig(gstreamer-1.0)
BuildRequires:  pkgconfig(opus)
BuildRequires:  pkgconfig(speex)
BuildRequires:  pkgconfig(theora)
BuildRequires:  pkgconfig(vpx)

%description
QXmpp is a cross-platform C++ XMPP client library based on Qt and C++.

%package -n %{name}%{sover}
Summary:        Qt XMPP Library
Group:          System/Libraries
Provides:       libqxmpp-qt5-0 = %{version}
Obsoletes:      libqxmpp-qt5-0 < %{version}

%description -n %{name}%{sover}
QXmpp is a cross-platform C++ XMPP client library based on Qt and C++.

%package -n %{name}-devel
Summary:        Qxmpp Development Files
Group:          Development/Libraries/C and C++
Requires:       %{name}%{sover} = %{version}
Requires:       pkgconfig(gstreamer-1.0)
Provides:       libqxmpp-qt5-devel = %{version}
Obsoletes:      libqxmpp-qt5-devel < %{version}

%description -n %{name}-devel
Development package for qxmpp.

%package doc
Summary:        Qxmpp library documentation
Group:          Documentation/HTML
BuildArch:      noarch

%description doc
This packages provides documentation of Qxmpp library API.

%prep
%setup -q -n qxmpp-%{version}
# Disable tests needing a network connection
sed -i 's,add_simple_test(qxmppserver),#add_simple_test(qxmppserver),' tests/CMakeLists.txt
sed -i 's,add_simple_test(qxmppcallmanager),#add_simple_test(qxmppcallmanager),' tests/CMakeLists.txt
sed -i 's,add_simple_test(qxmppiceconnection),#add_simple_test(qxmppiceconnection),' tests/CMakeLists.txt
sed -i 's,add_subdirectory(qxmpptransfermanager),#add_subdirectory(qxmpptransfermanager),' tests/CMakeLists.txt
sed -i 's,add_subdirectory(qxmppuploadrequestmanager),#add_subdirectory(qxmppuploadrequestmanager),' tests/CMakeLists.txt

%build
%cmake \
  -DWITH_SPEEX=ON \
  -DWITH_OPUS=ON \
  -DWITH_THEORA=ON \
  -DWITH_VPX=ON \
  -DWITH_GSTREAMER=ON \
  -DBUILD_DOCUMENTATION=ON \
  -DBUILD_EXAMPLES=ON \
  -DBUILD_TESTS=ON

%cmake_build

%install
%cmake_install
%fdupes %{buildroot}%{_datadir}/doc/qxmpp/

%check
export LD_LIBRARY_PATH=%{buildroot}%{_libdir}
%ctest

%post -n %{name}%{sover} -p /sbin/ldconfig
%postun -n %{name}%{sover} -p /sbin/ldconfig

%files -n %{name}%{sover}
%license LICENSE.LGPL
%doc AUTHORS CHANGELOG.md README.md
%{_libdir}/%{name}.so.*

%files -n %{name}-devel
%{_includedir}/qxmpp/
%{_libdir}/%{name}.so
%{_libdir}/cmake/qxmpp/
%{_libdir}/pkgconfig/qxmpp.pc

%files doc
%{_datadir}/doc/qxmpp/

%changelog
* Mon Aug  2 2021 Dmitriy Perlow <dap.darkness@gmail.com>
- update to 1.4.0:
  * Qt 6 port, including many undeprecations and some refactoring
  * Add XEP-0224: Attention manager
  * Implement MIX-MISC XEP-0407: Invitation message extension
  * New SCRAM-SHA3-512 and SCRAM-SHA-512 SASL algorithms
  * Client: Advertise stream management state
  * RosterManager: Cache roster if stream can be resumed
  * RosterManager: Enable MIX annotation for roster items
  * Bind IQ errors are now handled properly
  * Fix cached stream management packets are resent with the wrong account
  * TransferManager: Fix undefined behaviour when parsing features
  * OutgoingServer: Add missing 'to' and 'from' stream attributes
* Thu Sep 10 2020 Luigi Baldoni <aloisio@gmx.com>
- Enable gstreamer
* Thu Aug 27 2020 Dirk Mueller <dmueller@suse.com>
- update to 1.3.1:
  * The most important change of this release is the fix of CVE-2017-5603. QXmpp is
  not vulnerable to roster push attacks (CVE-2016-9928).
  - QXmppRosterIq: Set subscriptionType to NotSet correctly (#293, @melvo)
  - Fix `QXMPP_EXPORT` define when linking statically (#299, @leobasilio)
  - QXmppMessageReceiptManager: Ignore all error messages (#300, @lnjX)
  - QXmppCarbonManager: Fix CVE-2017-5603 (missing sender check) (#304, @lnjX)
  QXmpp complys with the XMPP Compliance Suites 2020 (XEP-0423) for client
  development in the Core, IM and Advanced Mobile suites now. For this prupose it
  has been updated to RFC6120 and RFC6121. ABI compatibility was kept with this
  release (apart from classes marked as 'NOT FINALIZED').
  - Port QXmppCallManager to GStreamer (#207, @olesalscheider)
  - Add XEP-0245: The /me Command (#276, @lnjX)
  - Add XEP-0357: Push Notifications: Enable/disable IQ (#271, @jbbgameich,
  @zatroxde)
  - Add XEP-0359: Unique and Stable Stanza IDs (#256, @lnjX)
  - Add XEP-0428: Fallback Indication (#253, @lnjX)
  - Update from RFC3920 to RFC6120:
  * Deprecate PaymentRequired stanza error condition as it was not adopted in
    RFC6120 (#277, @lnjX)
  * Add PolicyViolation stanza error condition added in RFC6120 (#279, @lnjX)
  * Add redirection URI from RFC6120 for Gone and Redirect conditions (#280,
    @lnjX)
  * Add 'by' attribute to QXmppStanza::Error from RFC6120 (#283, @lnjX)
  - Update from RFC3921 to RFC6121:
  * Add pre-approved presence subscriptions (#285, @lnjX):
  - Add 'approved' attribute to QXmppRosterIq
  - Add stream feature for pre-approved presence subscriptions
  * Add stream feature for roster versioning (#286, @lnjX)
  - Use QUuid by default to generate unique stanza IDs (#255, @lnjX)
  - Add roster extension for MIX-PAM (XEP-0405) (#175, @lnjX)
  - Update MAM to v0.6 (including namespace bump to `urn:xmpp:mam:2`) (#254,
  [#257], @lnjX)
  - Add not-authorized stream error condition in QXmppOutgoingClient (#191,
  @henry61024)
  - Add missing static service discovery features for supported message
  extensions (#287, @lnjX)
  - Add utility constructor to QXmppDataForm and QXmppDataForm::Field to make
  creation of forms easier (#273, @lnjX)
  - Make QXmpp work with projects using `QT_NO_KEYWORDS` (#258, @tomcucinotta)
  - Add hyperlinks to XEP references in the documentation (@lnjX)
  - Move from Travis-CI to GitHub Actions (#265, @jlaine)
  - Replace deprecated `qsrand()` and `qrand()` by QRandomGenerator (#267,
  @melvo)
  - Add tests for QXmppStanza::Error parsing (#279, @lnjX)
  - `QXmppStanza::Error::Condition::PaymentRequired`: The error condition was
  unused and not adopted in RFC6120
* Tue May 19 2020 Wolfgang Bauer <wbauer@tmo.at>
- Fix baselibs.conf following the sover bump
* Mon Apr  6 2020 Vinzenz Vietzke <vinz@vinzv.de>
- Update to 1.2.1. Changes since 1.1.0:
  * QXmppRegistrationManager: Fix failed and succeeded signals are both emitted
    on success
  * QXmppMessageReceiptManager: Fix receipts are sent on error messages
  * QXmppVCardManager: Fix clientVCardReceived() not emitted when IQ is from the
    bare JID of the user
  * QXmppRosterManager: Fix 'ask' attribute is included when renaming item
  * QXmppRosterIq: Add missing implementation of the copy constructor
  * Implement XEP-0077: In-band registration:
  * Add registration manager with full unit tests
  * Add `registered` and `remove` to the IQ
  * Implement XEP-0231: Bits of Binary
  * Add `QXmppClient::indexOfExtension<T>()`
  * Add QXmppStartTlsPacket to replace fixed XML data
  * Move TLS code to private QXmppTlsManager
  * Add private QXmppInternalClientExtensions to access private part of the
    client
  * Add utility methods to QXmppRegisterIq to create common requests
  * QXmppMucManager: Make it possible to handle stanzas not handled by the
    manager
  * Only send Client State Indication (CSI) states when connected
  * Fix no documentation is generated for QXmppStanza::Error and
    QXmppStreamFeatures
  * Fix some doxygen warnings and undocumented Q_PROPERTYs
  * Replace deprecated Q_FOREACH
  * Replace deprecated Q_ENUMS with Q_ENUM
  * Replace deprecated signal/slots syntax
  * Switch to Ubuntu Bionic for Travis-CI builds
  * Use QSharedDataPointers for QXmppRegisterIq, QXmppPubSubIq,
    QXmppDiscoveryIq, QXmppMam{Query,Result}Iq, QXmppStreamFeatures
  * Refactor QXmppPubSubIq and add missing tests
  * Refactor QXmppPresence and add missing tests
  * Replace manual xmlns writing by writeDefaultNamespace()
  * Use QT_VERSION_CHECK to generate QXMPP_VERSION
  * Add clang-format file
- Fixed shlib-policy-name-error libqxmpp2 (sover bump up to 3).
* Mon Nov 18 2019 Dmitriy Perlow <dap.darkness@gmail.com>
- Update to 1.1.0. Changes since 1.0.0:
  * Add support for SCRAM-SHA-1 and SCRAM-SHA-256;
  * Order SASL mechanisms to prefer the most secure;
  * Add XEP-0334, -0363, -0367, -0369 (partially), -0380, -0382;
  * Do not accept receipts from other resources of the used account;
  * cmake: Set minimum version before creating project() and bump to 3.3;
  * Deprecate QXmppClient extension getters;
  * Refactor data form media element, deprecate `QXmppDataForm::Media;
  * Replace deprecated `qSort()` by `std::sort()`;
  * Do not use deprecated `QSslSocket::setCaCertificates()`;
  * Modernize code by using `nullptr`, `override`, etc.;
  * Move attributes into private d-pointer for future ABI compatibility;
  * Use raw literals, range based loops and `auto`;
  * Fix potential SEGFAULT on connection error;
  * Fix `SO_VERSION` to 1: ABI has changed since last minor release;
  * Add CMake option for internal tests (`BUILD_INTERNAL_TESTS`).
- Disable tests needing a network connection += qxmppuploadrequestmanager.
- Fixed shlib-policy-name-error libqxmpp2 (sover bump up to 2).
* Tue May  7 2019 Jan Engelhardt <jengelh@inai.de>
- Fix SRPM group.
* Fri May  3 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 1.0.0. Changes since 0.8.3:
  * Drop Qt4 support
  * Fix phone numbers incorrectly read from / written to vCard
  * Make QXmppStream handle end of incoming stream
  * Allow QXmppJingleIq to have multiple contents.
  * Fix QXmppTransferManagerFix convering filename to a QUrl.
  * Do not ignore SSL errors by default
  * CMake based build system
  * Use C++11 compiler standard
  Check the CHANGELOG.md file for the complete list of changes
- Drop libqxmpp-qt5
- Run spec-cleaner
- Drop obsolete patch: libqxmpp-qt5.patch
- Trim marketing filler wording from description.
- Update the license tag to LGPL-2.1-or-later
* Sat Mar 14 2015 dap.darkness@gmail.com
- update to 0.8.3
  * Add a QXmppClient::sslErrors signal to report SSL errors.
  * Handle broken servers which send "bad-auth"
    instead of "not-authorized".
  * Fix a compilation issue with Qt 5.5 due to a missing include.
  * Do not install test cases.
  * Remove trailing comma after last item in enums.
* Fri Jan  9 2015 dap.darkness@gmail.com
- update to 0.8.2
  * Refactor HTML documentation so that "make docs" works in
    out-of-source builds.
  * Add support for Opus audio codec.
  * Enable error concealment for VPX video codec.
  * Use QString() instead of "" for default methods arguments,
    to enable building project which use QT_NO_CAST_FROM_ASCII.
  * Add support for legacy SSL.
  * Add XEP-0333: Chat Markers attributes to QXmppMessage.
  * Add QXmppClient::socketErrorString
    to retrieve socket error string.
  * Add equality/inequality operators for QXmppVCardIq.
  * Add "make check" command to run tests.
-packaging
  * Switched to tarball from github.
  * Added libqxmpp-qt5.patch to implement Qt5 alternative.
  * Switched to pkgconfig() at Requires section.
  * Broken old distros: SLE11, openSUSE~11.4.
  * Let make be verbose.
  * Added check section.
* Thu Mar 27 2014 dap.darkness@gmail.com
- update to 0.8.0
  * Add organizations info interface to QXmppVCardIq.
  * Remove deprecated QXmppPresence::Status type.
- Source URL was put back.
- Url tag and Source URL were updated to qxmpp.org.
* Sun Mar  9 2014 dap.darkness@gmail.com
- Source URL was temporary deleted to pass factory-auto.
* Sun Mar  9 2014 dap.darkness@gmail.com
- update to 0.7.6+git.2014.03.09
  * Added QPair include just in case.
  * Avoid keeping the source QDomDocument in QXmppElement.
    Serialize the node instead of keeping QDomElement
    with a ref to the original QDomDOcument.
  * QXmppElement::sourceDomElement().
  * Namespace-based matching for known elements.
  * Cover non-'x' extensions in tests.
  * Support other extensions besides 'x' in QXmppMessage.
  * Fixes to support Qt5.
  * Re-order member initialization (silences GCC warning).
  * Fixed possible memory leak in QXmppTransferManager.
  * Added missing assert for connecting signal in QXmppStream.
  * Fixed C-style pointer cast.
  * Fixed uninitialized pointers in QXmppOutgoingClientPrivate.
  * Fixed uninitialized pointer in QXmppCallPrivate.
  * Fixed uninitialized pointer in QXmppRtpAudioChannelPrivate.
  * Fixed uninitialized member in QXmppOutgoingClient.
  * Fix QXmppServer incoming connections with Qt5 (issue 175).
* Mon Aug 19 2013 dap.darkness@gmail.com
- Full VoIP support was enabled.
- Spec was fixed up via spec-cleaner.
* Fri Mar 22 2013 schwab@suse.de
- Override LIBDIR instead of moving the library manually
* Mon Mar 11 2013 dap.darkness@gmail.com
- update to 0.7.6
  * Add QXmppClient::insertExtension to insert an extension at a given index.
  * Disable Facebook/Google specific mechanisms if no corresponding credentials.
- Mistake at doc-subpackage description was fixed.
* Thu Dec 20 2012 dap.darkness@gmail.com
- update to 0.7.4
  * Add XEP-0249: Direct MUC Invitations attributes to QXmppMessage.
  * Add XEP-0045: Multi-User Chat attributes to QXmppPresence.
  * Improve GuiClient, stop using deprecated APIs.
  * Improve QXmppServer.
  * Improve QXmppTransferManager.
* Tue Sep  4 2012 nekolayer@yandex.ru
- changed to upstream url
  - package renamed
  - Update to version 0.7.1
  - Fix export of QXmppVCardPhone class.
  - New XEPs:
  * XEP-0033: Extended Stanza Addressing
  - Remove deprecated APIs:
  * QXmppRosterManager::rosterChanged()
  * QXmppConfiguration::sASLAuthMechanism()
  - Improve vCard support:
  * Add support for free-form descriptive text.
  * Make it possible to have several addresses.
  * Make it possible to have several e-mail addresses.
  * Make it possible to have several phone numbers.
  - Make it possible to set the client's extended information form (XEP-0128).
  - Make sure QXmppDiscoveryManager only emits results.
  - Fix XEP-0115 verification strings (remove duplicate features, sort form values)
  - Fix issues:
  * Issue 144: QXmppBookmarkConference autojoin parsing
  - Add support for see-other-host server change.
  - Add support for X-MESSENGER-OAUTH2 authentication for Windows Live Messenger.
  - Make it possible to disable non-SASL authentication.
  - Add QXmppClient::isAuthenticated() to query whether authentication has been
    performed.
* Mon Sep  3 2012 idonmez@suse.com
- Fix name for devel package
* Fri Aug 10 2012 dap.darkness@gmail.com
- update to 0.6.3.1
  * Source tree was sync with upstream.
  * The library became dynamic.
* Tue Jul  3 2012 dvaleev@suse.com
- fix ppc64 libdir
* Tue Mar  6 2012 nekolayer@yandex.ru
- update to 0.3.47
* Sun Jul 31 2011 nlminhtl@gmail.com
- first package
